@@ -10,6 +10,8 @@ from cognite.air.constants import (
     LEGAL_FIELD_TYPES,
     MA_FIELD_META_FIELDS,
     MA_FIELD_META_MODELVERSION,
+    MA_FIELD_META_MTDESCRIPTION,
+    MA_FIELD_META_MTNAME,
     SA_EXT_ID,
     SA_FIELD_META_DATA,
 )
@@ -80,6 +82,26 @@ class AIRClient:
     def model_version(self):
         return self._config.model_version
 
+    @property
+    def schedule_front_end_name(self):
+        return self._config.schedule_asset.metadata.get(MA_FIELD_META_MTNAME)
+
+    @schedule_front_end_name.setter
+    def schedule_front_end_name(self, name):
+        if name != self.schedule_front_end_name:
+            self._config.schedule_asset.metadata[MA_FIELD_META_MTNAME] = name
+            self.cognite_client.assets.update(self._config.schedule_asset)
+
+    @property
+    def schedule_front_end_description(self):
+        return self._config.schedule_asset.metadata.get(MA_FIELD_META_MTDESCRIPTION)
+
+    @schedule_front_end_description.setter
+    def schedule_front_end_description(self, description):
+        if description != self.schedule_front_end_description:
+            self._config.schedule_asset.metadata[MA_FIELD_META_MTDESCRIPTION] = description
+            self.cognite_client.assets.update(self._config.schedule_asset)
+
     def retrieve_fields(self, field_names: List[str]) -> List[AIR_TYPES]:
         if not isinstance(field_names, list) or not all(isinstance(s, str) for s in field_names):
             raise TypeError(f"Expected '{field_names}' to be a list of strings!")
